==> symfony_6.4.18+dfsg.orig.tar.xz: symfony-6.4.18/src/Symfony/Component/Intl/Resources/data/timezones/fr_CA.php <==
<?php

return [
    'Names' => [
        'Africa/Addis_Ababa' => 'heure d’Afrique orientale (Addis-Abeba)',
        'Africa/Algiers' => 'heure de l’Europe centrale (Alger)',
        'Africa/Asmera' => 'heure d’Afrique orientale (Asmara)',
        'Africa/Blantyre' => 'heure d’Afrique centrale (Blantyre)',
        'Africa/Bujumbura' => 'heure d’Afrique centrale (Bujumbura)',
        'Africa/Cairo' => 'heure de l’Europe de l’Est (Le Caire)',
        'Africa/Casablanca' => 'heure de l’Europe de l’Ouest (Casablanca)',
        'Africa/Ceuta' => 'heure de l’Europe centrale (Ceuta)',
        'Africa/Dar_es_Salaam' => 'heure d’Afrique orientale (Dar es Salaam)',
        'Africa/Djibouti' => 'heure d’Afrique orientale (Djibouti)',
        'Africa/El_Aaiun' => 'heure de l’Europe de l’Ouest (Laâyoune)',
        'Africa/Gaborone' => 'heure d’Afrique centrale (Gaborone)',
        'Africa/Harare' => 'heure d’Afrique centrale (Harare)',
        'Africa/Johannesburg' => 'heure normale d’Afrique du Sud (Johannesburg)',
        'Africa/Juba' => 'heure d’Afrique centrale (Juba)',
        'Africa/Kampala' => 'heure d’Afrique orientale (Kampala)',
        'Africa/Khartoum' => 'heure d’Afrique centrale (Khartoum)',
        'Africa/Kigali' => 'heure d’Afrique centrale (Kigali)',
        'Africa/Lubumbashi' => 'heure d’Afrique centrale (Lubumbashi)',
        'Africa/Lusaka' => 'heure d’Afrique centrale (Lusaka)',
        'Africa/Maputo' => 'heure d’Afrique centrale (Maputo)',
        'Africa/Maseru' => 'heure normale d’Afrique du Sud (Maseru)',
        'Africa/Mbabane' => 'heure normale d’Afrique du Sud (Mbabane)',
        'Africa/Mogadishu' => 'heure d’Afrique orientale (Mogadiscio)',
        'Africa/Nairobi' => 'heure d’Afrique orientale (Nairobi)',
        'Africa/Ndjamena' => 'heure d’Afrique de l’Ouest (Ndjamena)',
        'Africa/Tripoli' => 'heure de l’Europe de l’Est (Tripoli [Libye])',
        'Africa/Tunis' => 'heure de l’Europe centrale (Tunis)',
        'Africa/Windhoek' => 'heure d’Afrique centrale (Windhoek)',
        'America/Adak' => 'heure d’Hawaï-Aléoutiennes (Adak)',
        'America/Bahia_Banderas' => 'heure du Centre (Bahia de Banderas)',
        'America/Barbados' => 'heure de l’Atlantique (Barbade (La))',
        'America/Belize' => 'heure du Centre (Belize)',
        'America/Cancun' => 'heure de l’Est (Cancún)',
        'America/Cayenne' => 'heure de Guyane française (Cayenne)',
        'America/Cayman' => 'heure de l’Est (îles Caïmans)',
        'America/Chicago' => 'heure du Centre (Chicago)',
        'America/Chihuahua' => 'heure du Centre (Chihuahua)',
        'America/Coral_Harbour' => 'heure de l’Est (Atikokan)',
        'America/Costa_Rica' => 'heure du Centre (Costa Rica)',
        'America/Detroit' => 'heure de l’Est (Détroit)',
        'America/El_Salvador' => 'heure du Centre (El Salvador)',
        'America/Grand_Turk' => 'heure de l’Est (Grand Turk)',
        'America/Guatemala' => 'heure du Centre (Guatemala)',
        'America/Indiana/Knox' => 'heure du Centre (Knox [Indiana])',
        'America/Indiana/Marengo' => 'heure de l’Est (Marengo [Indiana])',
        'America/Indiana/Petersburg' => 'heure de l’Est (Petersburg [Indiana])',
        'America/Indiana/Tell_City' => 'heure du Centre (Tell City [Indiana])',
        'America/Indiana/Vevay' => 'heure de l’Est (Vevay [Indiana])',
        'America/Indiana/Vincennes' => 'heure de l’Est (Vincennes [Indiana])',
        'America/Indiana/Winamac' => 'heure de l’Est (Winamac [Indiana])',
        'America/Indianapolis' => 'heure de l’Est (Indianapolis)',
        'America/Iqaluit' => 'heure de l’Est (Iqaluit)',
        'America/Jamaica' => 'heure de l’Est (Jamaïque)',
        'America/Kentucky/Monticello' => 'heure de l’Est (Monticello [Kentucky])',
        'America/Los_Angeles' => 'heure du Pacifique (Los Angeles)',
        'America/Louisville' => 'heure de l’Est (Louisville)',
        'America/Managua' => 'heure du Centre (Managua)',
        'America/Matamoros' => 'heure du Centre (Matamoros)',
        'America/Menominee' => 'heure du Centre (Menominee)',
        'America/Merida' => 'heure du Centre (Mérida)',
        'America/Mexico_City' => 'heure du Centre (Mexico)',
        'America/Monterrey' => 'heure du Centre (Monterrey)',
        'America/Nassau' => 'heure de l’Est (Nassau)',
        'America/New_York' => 'heure de l’Est (New York)',
        'America/North_Dakota/Beulah' => 'heure du Centre (Beulah [Dakota du Nord])',
        'America/North_Dakota/Center' => 'heure du Centre (Center [Dakota du Nord])',
        'America/North_Dakota/New_Salem' => 'heure du Centre (New Salem [Dakota du Nord])',
        'America/Ojinaga' => 'heure du Centre (Ojinaga)',
        'America/Panama' => 'heure de l’Est (Panama)',
        'America/Port-au-Prince' => 'heure de l’Est (Port-au-Prince)',
        'America/Rankin_Inlet' => 'heure du Centre (Rankin Inlet)',
        'America/Regina' => 'heure du Centre (Regina)',
        'America/Resolute' => 'heure du Centre (Resolute)',
        'America/St_Johns' => 'heure de Terre-Neuve (St. John’s)',
        'America/St_Kitts' => 'heure de l’Atlantique (Saint-Christophe-et-Niévès)',
        'America/St_Thomas' => 'heure de l’Atlantique (Saint Thomas)',
        'America/Swift_Current' => 'heure du Centre (Swift Current)',
        'America/Tegucigalpa' => 'heure du Centre (Tegucigalpa)',
        'America/Tijuana' => 'heure du Pacifique (Tijuana)',
        'America/Toronto' => 'heure de l’Est (Toronto)',
        'America/Vancouver' => 'heure du Pacifique (Vancouver)',
        'America/Winnipeg' => 'heure du Centre (Winnipeg)',
        'Arctic/Longyearbyen' => 'heure de l’Europe centrale (Longyearbyen)',
        'Asia/Amman' => 'heure de l’Europe de l’Est (Amman)',
        'Asia/Beirut' => 'heure de l’Europe de l’Est (Beyrouth)',
        'Asia/Brunei' => 'heure du Brunéi (Brunei)',
        'Asia/Damascus' => 'heure de l’Europe de l’Est (Damas)',
        'Asia/Dhaka' => 'heure du Bangladesh (Dacca)',
        'Asia/Famagusta' => 'heure de l’Europe de l’Est (Famagouste)',
        'Asia/Gaza' => 'heure de l’Europe de l’Est (Gaza)',
        'Asia/Hebron' => 'heure de l’Europe de l’Est (Hébron)',
        'Asia/Macau' => 'heure de Chine (Macao)',
        'Asia/Nicosia' => 'heure de l’Europe de l’Est (Nicosie)',
        'Asia/Omsk' => 'heure d’Omsk',
        'Asia/Shanghai' => 'heure de Chine (Shanghai)',
        'Asia/Thimphu' => 'heure du Bhoutan (Thimphou)',
        'Atlantic/Canary' => 'heure de l’Europe de l’Ouest (îles Canaries)',
        'Atlantic/Faeroe' => 'heure de l’Europe de l’Ouest (îles Féroé)',
        'Atlantic/Madeira' => 'heure de l’Europe de l’Ouest (Madère)',
        'Europe/Amsterdam' => 'heure de l’Europe centrale (Amsterdam)',
        'Europe/Andorra' => 'heure de l’Europe centrale (Andorre)',
        'Europe/Athens' => 'heure de l’Europe de l’Est (Athènes)',
        'Europe/Belgrade' => 'heure de l’Europe centrale (Belgrade)',
        'Europe/Berlin' => 'heure de l’Europe centrale (Berlin)',
        'Europe/Bratislava' => 'heure de l’Europe centrale (Bratislava)',
        'Europe/Brussels' => 'heure de l’Europe centrale (Bruxelles)',
        'Europe/Bucharest' => 'heure de l’Europe de l’Est (Bucarest)',
        'Europe/Budapest' => 'heure de l’Europe centrale (Budapest)',
        'Europe/Busingen' => 'heure de l’Europe centrale (Büsingen)',
        'Europe/Chisinau' => 'heure de l’Europe de l’Est (Chisinau)',
        'Europe/Copenhagen' => 'heure de l’Europe centrale (Copenhague)',
        'Europe/Gibraltar' => 'heure de l’Europe centrale (Gibraltar)',
        'Europe/Helsinki' => 'heure de l’Europe de l’Est (Helsinki)',
        'Europe/Isle_of_Man' => 'heure moyenne de Greenwich (île de Man)',
        'Europe/Kaliningrad' => 'heure de l’Europe de l’Est (Kaliningrad)',
        'Europe/Kiev' => 'heure de l’Europe de l’Est (Kiev)',
        'Europe/Lisbon' => 'heure de l’Europe de l’Ouest (Lisbonne)',
        'Europe/Ljubljana' => 'heure de l’Europe centrale (Ljubljana)',
        'Europe/Luxembourg' => 'heure de l’Europe centrale (Luxembourg)',
        'Europe/Madrid' => 'heure de l’Europe centrale (Madrid)',
        'Europe/Malta' => 'heure de l’Europe centrale (Malte)',
        'Europe/Mariehamn' => 'heure de l’Europe de l’Est (Mariehamn)',
        'Europe/Monaco' => 'heure de l’Europe centrale (Monaco)',
        'Europe/Oslo' => 'heure de l’Europe centrale (Oslo)',
        'Europe/Paris' => 'heure de l’Europe centrale (Paris)',
        'Europe/Podgorica' => 'heure de l’Europe centrale (Podgorica)',
        'Europe/Prague' => 'heure de l’Europe centrale (Prague)',
        'Europe/Riga' => 'heure de l’Europe de l’Est (Riga)',
        'Europe/Rome' => 'heure de l’Europe centrale (Rome)',
        'Europe/San_Marino' => 'heure de l’Europe centrale (Saint-Marin)',
        'Europe/Sarajevo' => 'heure de l’Europe centrale (Sarajevo)',
        'Europe/Skopje' => 'heure de l’Europe centrale (Skopje)',
        'Europe/Sofia' => 'heure de l’Europe de l’Est (Sofia)',
        'Europe/Stockholm' => 'heure de l’Europe centrale (Stockholm)',
        'Europe/Tallinn' => 'heure de l’Europe de l’Est (Tallinn)',
        'Europe/Tirane' => 'heure de l’Europe centrale (Tirana)',
        'Europe/Vaduz' => 'heure de l’Europe centrale (Vaduz)',
        'Europe/Vatican' => 'heure de l’Europe centrale (Vatican)',
        'Europe/Vienna' => 'heure de l’Europe centrale (Vienne)',
        'Europe/Vilnius' => 'heure de l’Europe de l’Est (Vilnius)',
        'Europe/Warsaw' => 'heure de l’Europe centrale (Varsovie)',
        'Europe/Zagreb' => 'heure de l’Europe centrale (Zagreb)',
        'Europe/Zurich' => 'heure de l’Europe centrale (Zurich)',
        'Indian/Antananarivo' => 'heure d’Afrique orientale (Antananarivo)',
        'Indian/Chagos' => 'heure de l’océan Indien (Chagos)',
        'Indian/Comoro' => 'heure d’Afrique orientale (Comores)',
        'Indian/Mayotte' => 'heure d’Afrique orientale (Mayotte)',
        'Indian/Reunion' => 'heure de la Réunion',
        'Pacific/Honolulu' => 'heure d’Hawaï-Aléoutiennes (Honolulu)',
        'Pacific/Niue' => 'heure de Nioué (Niue)',
        'Pacific/Palau' => 'heure des Palaos (Palau)',
    ],
    'Meta' => [],
];

==> symfony_7.4.3+dfsg.orig.tar.xz: symfony-7.4.3/src/Symfony/Component/Intl/Resources/data/timezones/fr_CA.php <==
<?php

return [
    'Names' => [
        'Africa/Addis_Ababa' => 'heure d’Afrique orientale (Addis-Abeba)',
        'Africa/Algiers' => 'heure de l’Europe centrale (Alger)',
        'Africa/Asmera' => 'heure d’Afrique orientale (Asmara)',
        'Africa/Asmara' => 'heure d’Afrique orientale (Asmara)',
        'Africa/Blantyre' => 'heure d’Afrique centrale (Blantyre)',
        'Africa/Bujumbura' => 'heure d’Afrique centrale (Bujumbura)',
        'Africa/Cairo' => 'heure de l’Europe de l’Est (Le Caire)',
        'Africa/Casablanca' => 'heure de l’Europe de l’Ouest (Casablanca)',
        'Africa/Ceuta' => 'heure de l’Europe centrale (Ceuta)',
        'Africa/Dar_es_Salaam' => 'heure d’Afrique orientale (Dar es Salaam)',
        'Africa/Djibouti' => 'heure d’Afrique orientale (Djibouti)',
        'Africa/El_Aaiun' => 'heure de l’Europe de l’Ouest (Laâyoune)',
        'Africa/Gaborone' => 'heure d’Afrique centrale (Gaborone)',
        'Africa/Harare' => 'heure d’Afrique centrale (Harare)',
        'Africa/Johannesburg' => 'heure normale d’Afrique du Sud (Johannesburg)',
        'Africa/Juba' => 'heure d’Afrique centrale (Juba)',
        'Africa/Kampala' => 'heure d’Afrique orientale (Kampala)',
        'Africa/Khartoum' => 'heure d’Afrique centrale (Khartoum)',
        'Africa/Kigali' => 'heure d’Afrique centrale (Kigali)',
        'Africa/Lubumbashi' => 'heure d’Afrique centrale (Lubumbashi)',
        'Africa/Lusaka' => 'heure d’Afrique centrale (Lusaka)',
        'Africa/Maputo' => 'heure d’Afrique centrale (Maputo)',
        'Africa/Maseru' => 'heure normale d’Afrique du Sud (Maseru)',
        'Africa/Mbabane' => 'heure normale d’Afrique du Sud (Mbabane)',
        'Africa/Mogadishu' => 'heure d’Afrique orientale (Mogadiscio)',
        'Africa/Nairobi' => 'heure d’Afrique orientale (Nairobi)',
        'Africa/Ndjamena' => 'heure d’Afrique de l’Ouest (Ndjamena)',
        'Africa/Tripoli' => 'heure de l’Europe de l’Est (Tripoli [Libye])',
        'Africa/Tunis' => 'heure de l’Europe centrale (Tunis)',
        'Africa/Windhoek' => 'heure d’Afrique centrale (Windhoek)',
        'America/Adak' => 'heure d’Hawaï-Aléoutiennes (Adak)',
        'America/Bahia_Banderas' => 'heure du Centre (Bahia de Banderas)',
        'America/Barbados' => 'heure de l’Atlantique (Barbade (La))',
        'America/Belize' => 'heure du Centre (Belize)',
        'America/Cancun' => 'heure de l’Est (Cancún)',
        'America/Cayenne' => 'heure de Guyane française (Cayenne)',
        'America/Cayman' => 'heure de l’Est (îles Caïmans)',
        'America/Chicago' => 'heure du Centre (Chicago)',
        'America/Chihuahua' => 'heure du Centre (Chihuahua)',
        'America/Coral_Harbour' => 'heure de l’Est (Atikokan)',
        'America/Atikokan' => 'heure de l’Est (Atikokan)',
        'America/Costa_Rica' => 'heure du Centre (Costa Rica)',
        'America/Detroit' => 'heure de l’Est (Détroit)',
        'America/El_Salvador' => 'heure du Centre (El Salvador)',
        'America/Grand_Turk' => 'heure de l’Est (Grand Turk)',
        'America/Guatemala' => 'heure du Centre (Guatemala)',
        'America/Indiana/Knox' => 'heure du Centre (Knox [Indiana])',
        'America/Indiana/Marengo' => 'heure de l’Est (Marengo [Indiana])',
        'America/Indiana/Petersburg' => 'heure de l’Est (Petersburg [Indiana])',
        'America/Indiana/Tell_City' => 'heure du Centre (Tell City [Indiana])',
        'America/Indiana/Vevay' => 'heure de l’Est (Vevay [Indiana])',
        'America/Indiana/Vincennes' => 'heure de l’Est (Vincennes [Indiana])',
        'America/Indiana/Winamac' => 'heure de l’Est (Winamac [Indiana])',
        'America/Indianapolis' => 'heure de l’Est (Indianapolis)',
        'America/Indiana/Indianapolis' => 'heure de l’Est (Indianapolis)',
        'America/Iqaluit' => 'heure de l’Est (Iqaluit)',
        'America/Jamaica' => 'heure de l’Est (Jamaïque)',
        'America/Kentucky/Monticello' => 'heure de l’Est (Monticello [Kentucky])',
        'America/Los_Angeles' => 'heure du Pacifique (Los Angeles)',
        'America/Louisville' => 'heure de l’Est (Louisville)',
        'America/Kentucky/Louisville' => 'heure de l’Est (Louisville)',
        'America/Managua' => 'heure du Centre (Managua)',
        'America/Matamoros' => 'heure du Centre (Matamoros)',
        'America/Menominee' => 'heure du Centre (Menominee)',
        'America/Merida' => 'heure du Centre (Mérida)',
        'America/Mexico_City' => 'heure du Centre (Mexico)',
        'America/Monterrey' => 'heure du Centre (Monterrey)',
        'America/Nassau' => 'heure de l’Est (Nassau)',
        'America/New_York' => 'heure de l’Est (New York)',
        'America/North_Dakota/Beulah' => 'heure du Centre (Beulah [Dakota du Nord])',
        'America/North_Dakota/Center' => 'heure du Centre (Center [Dakota du Nord])',
        'America/North_Dakota/New_Salem' => 'heure du Centre (New Salem [Dakota du Nord])',
        'America/Ojinaga' => 'heure du Centre (Ojinaga)',
        'America/Panama' => 'heure de l’Est (Panama)',
        'America/Port-au-Prince' => 'heure de l’Est (Port-au-Prince)',
        'America/Rankin_Inlet' => 'heure du Centre (Rankin Inlet)',
        'America/Regina' => 'heure du Centre (Regina)',
        'America/Resolute' => 'heure du Centre (Resolute)',
        'America/St_Johns' => 'heure de Terre-Neuve (St. John’s)',
        'America/St_Kitts' => 'heure de l’Atlantique (Saint-Christophe-et-Niévès)',
        'America/St_Thomas' => 'heure de l’Atlantique (Saint Thomas)',
        'America/Swift_Current' => 'heure du Centre (Swift Current)',
        'America/Tegucigalpa' => 'heure du Centre (Tegucigalpa)',
        'America/Tijuana' => 'heure du Pacifique (Tijuana)',
        'America/Toronto' => 'heure de l’Est (Toronto)',
        'America/Vancouver' => 'heure du Pacifique (Vancouver)',
        'America/Winnipeg' => 'heure du Centre (Winnipeg)',
        'Arctic/Longyearbyen' => 'heure de l’Europe centrale (Longyearbyen)',
        'Asia/Amman' => 'heure de l’Europe de l’Est (Amman)',
        'Asia/Beirut' => 'heure de l’Europe de l’Est (Beyrouth)',
        'Asia/Brunei' => 'heure du Brunéi (Brunei)',
        'Asia/Damascus' => 'heure de l’Europe de l’Est (Damas)',
        'Asia/Dhaka' => 'heure du Bangladesh (Dacca)',
        'Asia/Famagusta' => 'heure de l’Europe de l’Est (Famagouste)',
        'Asia/Gaza' => 'heure de l’Europe de l’Est (Gaza)',
        'Asia/Hebron' => 'heure de l’Europe de l’Est (Hébron)',
        'Asia/Macau' => 'heure de Chine (Macao)',
        'Asia/Nicosia' => 'heure de l’Europe de l’Est (Nicosie)',
        'Asia/Omsk' => 'heure d’Omsk',
        'Asia/Shanghai' => 'heure de Chine (Shanghai)',
        'Asia/Thimphu' => 'heure du Bhoutan (Thimphou)',
        'Atlantic/Canary' => 'heure de l’Europe de l’Ouest (îles Canaries)',
        'Atlantic/Faeroe' => 'heure de l’Europe de l’Ouest (îles Féroé)',
        'Atlantic/Faroe' => 'heure de l’Europe de l’Ouest (îles Féroé)',
        'Atlantic/Madeira' => 'heure de l’Europe de l’Ouest (Madère)',
        'Europe/Amsterdam' => 'heure de l’Europe centrale (Amsterdam)',
        'Europe/Andorra' => 'heure de l’Europe centrale (Andorre)',
        'Europe/Athens' => 'heure de l’Europe de l’Est (Athènes)',
        'Europe/Belgrade' => 'heure de l’Europe centrale (Belgrade)',
        'Europe/Berlin' => 'heure de l’Europe centrale (Berlin)',
        'Europe/Bratislava' => 'heure de l’Europe centrale (Bratislava)',
        'Europe/Brussels' => 'heure de l’Europe centrale (Bruxelles)',
        'Europe/Bucharest' => 'heure de l’Europe de l’Est (Bucarest)',
        'Europe/Budapest' => 'heure de l’Europe centrale (Budapest)',
        'Europe/Busingen' => 'heure de l’Europe centrale (Büsingen)',
        'Europe/Chisinau' => 'heure de l’Europe de l’Est (Chișinău)',
        'Europe/Copenhagen' => 'heure de l’Europe centrale (Copenhague)',
        'Europe/Gibraltar' => 'heure de l’Europe centrale (Gibraltar)',
        'Europe/Helsinki' => 'heure de l’Europe de l’Est (Helsinki)',
        'Europe/Isle_of_Man' => 'heure moyenne de Greenwich (île de Man)',
        'Europe/Kaliningrad' => 'heure de l’Europe de l’Est (Kaliningrad)',
        'Europe/Kiev' => 'heure de l’Europe de l’Est (Kiev)',
        'Europe/Kyiv' => 'heure de l’Europe de l’Est (Kiev)',
        'Europe/Lisbon' => 'heure de l’Europe de l’Ouest (Lisbonne)',
        'Europe/Ljubljana' => 'heure de l’Europe centrale (Ljubljana)',
        'Europe/Luxembourg' => 'heure de l’Europe centrale (Luxembourg)',
        'Europe/Madrid' => 'heure de l’Europe centrale (Madrid)',
        'Europe/Malta' => 'heure de l’Europe centrale (Malte)',
        'Europe/Mariehamn' => 'heure de l’Europe de l’Est (Mariehamn)',
        'Europe/Monaco' => 'heure de l’Europe centrale (Monaco)',
        'Europe/Oslo' => 'heure de l’Europe centrale (Oslo)',
        'Europe/Paris' => 'heure de l’Europe centrale (Paris)',
        'Europe/Podgorica' => 'heure de l’Europe centrale (Podgorica)',
        'Europe/Prague' => 'heure de l’Europe centrale (Prague)',
        'Europe/Riga' => 'heure de l’Europe de l’Est (Riga)',
        'Europe/Rome' => 'heure de l’Europe centrale (Rome)',
        'Europe/San_Marino' => 'heure de l’Europe centrale (Saint-Marin)',
        'Europe/Sarajevo' => 'heure de l’Europe centrale (Sarajevo)',
        'Europe/Skopje' => 'heure de l’Europe centrale (Skopje)',
        'Europe/Sofia' => 'heure de l’Europe de l’Est (Sofia)',
        'Europe/Stockholm' => 'heure de l’Europe centrale (Stockholm)',
        'Europe/Tallinn' => 'heure de l’Europe de l’Est (Tallinn)',
        'Europe/Tirane' => 'heure de l’Europe centrale (Tirana)',
        'Europe/Vaduz' => 'heure de l’Europe centrale (Vaduz)',
        'Europe/Vatican' => 'heure de l’Europe centrale (Vatican)',
        'Europe/Vienna' => 'heure de l’Europe centrale (Vienne)',
        'Europe/Vilnius' => 'heure de l’Europe de l’Est (Vilnius)',
        'Europe/Warsaw' => 'heure de l’Europe centrale (Varsovie)',
        'Europe/Zagreb' => 'heure de l’Europe centrale (Zagreb)',
        'Europe/Zurich' => 'heure de l’Europe centrale (Zurich)',
        'Indian/Antananarivo' => 'heure d’Afrique orientale (Antananarivo)',
        'Indian/Chagos' => 'heure de l’océan Indien (Chagos)',
        'Indian/Comoro' => 'heure d’Afrique orientale (Comores)',
        'Indian/Mayotte' => 'heure d’Afrique orientale (Mayotte)',
        'Indian/Reunion' => 'heure de la Réunion',
        'Pacific/Honolulu' => 'heure normale d’Hawaï-Aléoutiennes (Honolulu)',
        'Pacific/Niue' => 'heure de Nioué (Niue)',
        'Pacific/Palau' => 'heure des Palaos (Palau)',
    ],
    'Meta' => [],
];
